Format to STAC collection name for some commonly used collections and STAC endpoints
Usage
as.collection(x, endpoint = as.endpoint("PlanetaryComputer"))Format to STAC collection name for some commonly used collections and STAC endpoints
as.collection(x, endpoint = as.endpoint("PlanetaryComputer"))