Methods for evaluating matching results
Details
This function uses the [cobalt::bal.tab()] function to generate balance statistics from the [MatchIt::matchit()] call. If the argument `covariate_overlap` is set to `TRUE`, the function calls [cobalt::bal.plot()] and returns density plots for the all covariates for control and treatment groups. If the argument `love_plot` is set to `TRUE`, a Love plot of Standardizes Mean Difference is generated with [cobalt::bal.plot()].