Calculated shortest geographic distance to OpenStreetMap road features
Arguments
- x
SpatRaster or SpatVector for which distances are calculated
- values
Character vector of road categories to be included (see https://wiki.openstreetmap.org/wiki/Key:highway) or a single road category with suffix "+" to include all categories including and above the selected category. Set to NULL to include all values.
- timeout
Numeric (seconds)
- osm_bbox
Bounding box for OSM feature retrieval, as numeric vector or character string of administrative name (see
osmdata::getbb)